# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]

## [2023.8.0]

### Added
- initial release

[Unreleased]: https://github.com/yaq-project/proxr-protocol/compare/v2023.8.0...main
[2023.8.0]: https://github.com/yaq-project/proxr-protocol/tags/v2023.8.0
